*Ford Youth Vulunerability
*Enterpreneurship in MENA region **
* By Caroline Krafft & Reham Rizk
*Data work do file
*v6
*Original 11/19/17 
*Updated 2020.09.04
*CK

** Data Cleaning *

** Restrictions :
// 1. Egypt 2012, Jordan 2016 and Tunisia 2014**
// 2. Working age population

use "Data/Integrated data/Integrated LMPs v3.0.dta", clear

keep if round==2012 | round==2016 | round==2014

** Country**
tab country, nol

gen cty =. 
replace cty=2 if country ==400
replace cty=1 if country ==818
replace cty=3 if country ==788

lab def cty 1 "Egypt 2012" 2 "Jordan 2016" 3 "Tunisia 2014", modify
lab val cty cty 
tab cty
 
** Restrict to working age population **
keep if age>=15 & age<=64

*Labor market status (Sepearte both UFW and Self-employed)
gen lmst=.
*Wage worker
replace lmst=3 if usempstp==1 & usemp1==1
*Employer
replace lmst=1 if usempstp==2 & usemp1==1
*Self-employed or UFW
replace lmst=2 if (usempstp==3 | usempstp==4) & usemp1==1

*Unemployed, standard market definition
replace lmst=4 if usemp1==0 & unempsr1==1
*OLF
replace lmst=5 if usemp1==0 & unempsr1==0

label define Llmst 1 "Employer" 2 "Self-Employed" 3 "Wage worker" 4 "Unemployed" 5 "OLF" 

label values lmst Llmst
lab var lmst "Labor market status"

tabu uswrkstsr1 lmst, miss

table sex round lmst

*N issues for women for sure

*Labor market status (Separate UFW and Self-employed to check)
******************************************************
gen lmsts=.
*Wage worker
replace lmsts=4 if usempstp==1 & usemp1==1
*Employer
replace lmsts=1 if usempstp==2 & usemp1==1
*Self-employed 
replace lmsts=2 if usempstp==3 & usemp1==1
*UFW
replace lmsts=3 if usempstp==4 & usemp1==1

*Unemployed, standard market definition
replace lmsts=5 if usemp1==0 & unempsr1==1
*OLF
replace lmsts=6 if usemp1==0 & unempsr1==0

label define Llmsts 1 "Employer" 2 "Self-Employed" 3 "Unpaid family worker" 4 "Wage worker" 5 "Unemployed" 6 "OLF" 

label values lmsts Llmsts
lab var lmst "Labor market status 2"

tabu uswrkstsr1 lmsts, miss

table sex round lmsts

****************************************************
*** Reviewer question: why we combine both self-employed and UFW ?**
****************************************************
tab lmsts sex if age>=15 & age<=64 [aw=expan_indiv], col nofreq

****************
****Covariates
****************

*Age group
tabu agegrp1

*Age group for unemployment
	
gen ageg =.
replace ageg=1 if age >=15 & age <=19
replace ageg=2 if age >=20 & age <=24
replace ageg=3 if age >=25 & age <=29
replace ageg=4 if age >=30 & age <=34 
replace ageg=5 if age >=35 & age <.
lab def ageg 1 "15-19" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35+", replace 
lab val ageg ageg


*Ever married
gen evrmarr=0 if marital==1
replace evrmarr=1 if marital>=2 & marital<=4

tab evrmarr marital, miss

la def Levrmarr 0 "Never married" 1 "Ever married"
la val evrmarr Levrmarr

*********************
** Education**
**************

tab educ1d

recode educ1d (1/2=1)(3=2)(4=3)(5/7=4), gen(educ_4cat)

label define Leduc_4cat 1 "No education" 2" Basic" 3 "Secondary" 4" Higher Education"

tabu educ_4cat educ1d, miss

label val educ_4cat Leduc_4cat
label var educ_4cat "Education level (four categories)"

**********************
* Social Class *
**********************

** Father's education**

codebook fteducst

recode fteducst (1/2=1)(3=2)(4=3)(5/6=4), gen(fteduc_4cat)

la val fteduc_4cat Leduc_4cat

tabu fteduc_4cat fteducst, miss

label variable fteduc_4cat "Father education level (four categories)"

*Mother's education

codebook mteducst

recode mteducst (1/2=1)(3=2)(4=3)(5/6=4), gen(mteduc_4cat)

la val mteduc_4cat Leduc_4cat
tabu mteduc_4cat mteducst, miss

label variable mteduc_4cat "Mother education level (four categories)"

* Categories of father's work status**
tabu ftempst

recode ftempst (1=3) (2=1) (3=2) (4=2) (5/6=4), gen(ftempst_4cat)

la def Lempst_4cat 1 "Employer" 2 "Self-Employed" 3 "Wage worker" 4 "Not employed/missing"

la val ftempst_4cat Lempst_4cat

la var ftempst_4cat "Father's emp. st. (four categories)"
tabu ftempst_4cat ftempst, miss


*Categories of mother's work status
tabu mtempst

recode mtempst (3/4=1) (2=1) (1=2) (5/6=3), gen(mtempst_3cat)


la def Lempst_3cat  1 "Employer or self-employed" 2 "Wage worker" 3 "Not employed/missing"

la val mtempst_3cat Lempst_3cat

la var mtempst_3cat "Mother's emp. st. (three categories)"
tabu mtempst_3cat mtempst, miss


*****Merge in full income

merge 1:1 indid using "Data/Egypt/ELMPS 2012 full income for integration.dta"

tabu _merge round
drop if _merge==2
drop _merge

*Undoing PPP
replace ipreinc=ipreinc*3.51

merge 1:1 indid using "Data/Tunisia/TLMPS 2014 full income for integration.dta", update

*Undoing PPP and 2012 terms

replace ipreinc=ipreinc*(167.1/148.9)*.79 if round==2014

tabu _merge round
drop if _merge==2
drop _merge

gen lipreinc=ln(ipreinc)
sum lipreinc, detail

gen lmnthwg=ln(mnthwg)
sum lmnthwg, detail

save "Data/Integrated LMPs v3.0.Entrep.dta", replace


***********
*Job Satis. 
***********



** Tunisia**

use "Data/Tunisia/TLMPS 2014 v2.1 all.dta", clear

replace indid="788"+indid

destring round, replace

	
keep indid round v667 v668_1 v668_2 v668_3 v668_4 v668_5 v668_6 v668_7 v668_8

save "Data/TLMPS 2014 Job Satis.dta", replace

*Egypt*

use "Data/Egypt/elmps 2012 xs v2.3 all.dta", clear

replace indid="818"+indid

destring round, replace

keep round indid q5167 q5168a q5168b q5168c q5168d q5168e q5168f q5168g q5168h

save "Data/ELMPS 2012 Job satis.dta", replace 


* Jordan*
	
use "Data/Jordan/JLMPS 2016 xs v1.1.dta", clear
	
replace indid="400"+indid
	
destring round, replace
	
keep round indid q6174 q6175_1 q6175_2 q6175_3 q6175_4 q6175_5 q6175_6 q6175_7 q6175_8	
	
save "Data/2016 JLMPS Job Satis.dta", replace

* Merge *

use "Data/Integrated LMPs v3.0.Entrep.dta", replace  

merge 1:1 indid using "Data/2016 JLMPS Job Satis.dta"	
tab _merge
tab _merge if age>=15 & age<=64
drop if _merge==2
drop _merge	

merge 1:1 indid using "Data/ELMPS 2012 Job satis.dta"	 
tab _merge
tab _merge if age>=15 & age<=64
drop if _merge==2
drop _merge	

merge 1:1 indid using "Data/TLMPS 2014 Job satis.dta"	 
tab _merge
tab _merge if age>=15 & age<=64
drop if _merge==2
drop _merge	

	
rename (q5168a q5168b q5168c q5168d q5168e q5168f q5168g q5168h) (q5168_1 q5168_2 q5168_3 q5168_4 q5168_5 q5168_6 q5168_7 q5168_8)	
	
forvalues i = 1(1)8 {

gen satis`i' =   100 if (q6175_`i'>=5 & q6175_`i'<.) | (v668_`i'>=5  & v668_`i'<6 )| (q5168_`i'>=5 & q5168_`i'<6)
 
replace satis`i'=0 if (q6175_`i'>=1 & q6175_`i'<=4) | (v668_`i'>1 & v668_`i'<=4) | (q5168_`i'>=1 & q5168_`i'<=4)

la val satis`i' satisf

}

la var satis1 "Satisfied with job security?"
la var satis2 "Satisfied with earnings?"
la var satis3 "Satisfied with type of work you do?"
la var satis4 "Satisfied with number of working hours?"
la var satis5 "Satisfied with work schedule?"
la var satis6 "Satisfied with working conditions?"
la var satis7 "Satisfied with distance to job?"
la var satis8 "Satisfied with job matching qualifications?"

keep if age>=15 & age<=64
keep if lmst!=.
drop if lmst>=4

keep satis1 satis2 satis3 satis4 satis5 satis6 satis7 satis8 lmst expan_indiv cty indid


save "Data/Integrated LMPs v3.0 Job Satisf.dta", replace





