
*Ford Youth Vulunerability
*Enterpreneurship in MENA region **
* By Caroline Krafft & Reham Rizk
*Models
*v11
*Original 11/19/17 
*Updated 2020.09.04
*CK

use "Data/Integrated LMPs v3.0.Entrep.dta", replace  

set matsize 1000

estimates clear

set scheme s1mono

****** Multinomial Logit Model*************

table sex cty lmst

*Women do not have enough N to run separately
** So we will run the MNL for the whole sample 
** And for men only as a SA

** Model 1: all employment status are used *** 
***************************************************

foreach num2 of numlist 2012 2014 2016 {
  
mlogit lmst i.sex b6.agegrp1 i.educ_4cat i.urban i.evrmar i.fteduc_4cat i.mteduc_4cat ib3.ftempst_4cat ///
ib2.mtempst_3cat i.gov [aw=expan_indiv] if round==`num2' , rrr b(3) 

estimates store est1_`num2'

foreach num1 of numlist 1/5 {

estimates restore est1_`num2'


margins, dydx(sex agegrp1 educ_4cat urban evrmar fteduc_4cat mteduc_4cat ftempst_4cat ///
mtempst_3cat) post  predict(outcome(`num1'))

estimates store mfx1_`num2'_`num1'

}

*Men only
  
mlogit lmst i.sex b6.agegrp1 i.educ_4cat i.urban i.evrmar i.fteduc_4cat i.mteduc_4cat ib3.ftempst_4cat ///
ib2.mtempst_3cat i.gov [aw=expan_indiv] if round==`num2' & sex==1, rrr b(3) 

estimates store est1_`num2'_men

foreach num1 of numlist 1/5 {

estimates restore est1_`num2'_men

margins, dydx(sex agegrp1 educ_4cat urban evrmar fteduc_4cat mteduc_4cat ftempst_4cat ///
mtempst_3cat) post  predict(outcome(`num1'))


estimates store mfx1_`num2'_`num1'_men

}


}
 
 
*baseline probabilites 
 

foreach num2 of numlist 2012 2014 2016 {

foreach num1 of numlist 1/5 {

estimates restore est1_`num2'

margins, pr(outcome(`num1')) at(sex=1 agegrp1=6 educ_4cat=1 urban=1 evrmar=0 ///
fteduc_4cat=1 mteduc_4cat=1 ftempst_4cat=3 mtempst_3cat=2)

}

*Men only
  
foreach num1 of numlist 1/5 {

estimates restore est1_`num2'_men

margins, pr(outcome(`num1')) at(sex=1 agegrp1=6 educ_4cat=1 urban=1 evrmar=0 ///
fteduc_4cat=1 mteduc_4cat=1 ftempst_4cat=3 mtempst_3cat=2)


}


}
 
  
 
 
*Output 
esttab est1_* using "Graphs and Tables/ent_mlogit_rrr.csv", ///
replace  cells(b(star fmt(%9.3f)) se(par)) nobase  ///     
stats(N r2, fmt(%9.0g %9.3f)) label  ///
mlabel("Multinomial Logit of Employment status relative risk ratios") ///
refcat(2.sex "Sex (male omit.)"  4.agegrp1 "Age group (30-39 omit.)" ///
 2.educ_4cat "Education (less than basic omit.)" 1.evrmarr "Ever married (never omit.)" ///
 2.urban "Residence (urban omit.)"  2.fteduc_4cat "Father's education (less than basic omit.)" ///
 2.mteduc_4cat "Mother's education (less than basic omit.)" 1.ftempst_4cat "Father's employment status (wage omit.)" ///
 1.mtempst_3cat "Mother's employment status (wage omit.)" ///
 , nolabel) eform ///
nobase noomit indicate(Governorates included = *gov*)


esttab mfx1_* using "Graphs and Tables/ent_mlogit_mfx.csv", ///
replace  cells(b(star fmt(%9.3f)) se(par)) nobase  ///     
stats(N r2, fmt(%9.0g %9.3f)) label  ///
mlabel("Multinomial Logit of Employment status relative risk ratios") ///
refcat(2.sex "Sex (male omit.)"  4.agegrp1 "Age group (30-39 omit.)" ///
 2.educ_4cat "Education (less than basic omit.)" 1.evrmarr "Ever married (never omit.)" ///
 2.urban "Residence (urban omit.)"  2.fteduc_4cat "Father's education (less than basic omit.)" ///
 2.mteduc_4cat "Mother's education (less than basic omit.)" 1.ftempst_4cat "Father's employment status (wage omit.)" ///
 1.mtempst_3cat "Mother's employment status (wage omit.)" ///
 , nolabel) ///
 noomit
 

 
********************************************
*Sensitivity analyses: just age, education
********************************************

***********Age

 
foreach num2 of numlist 2012 2014 2016 {
  
mlogit lmst i.sex b6.agegrp1  [aw=expan_indiv] if round==`num2' , rrr b(3) 

estimates store estSA1_`num2'

foreach num1 of numlist 1/5 {

estimates restore estSA1_`num2'


margins, dydx(sex agegrp1 ) post  predict(outcome(`num1'))

estimates store mfxSA1_`num2'_`num1'

}

*Men only
  
mlogit lmst i.sex b6.agegrp1 [aw=expan_indiv] if round==`num2' & sex==1, rrr b(3) 

estimates store estSA1_`num2'_men

foreach num1 of numlist 1/5 {

estimates restore estSA1_`num2'_men

margins, dydx(sex agegrp1) post  predict(outcome(`num1'))


estimates store mfxSA1_`num2'_`num1'_men

}


}


**********Age, education

 
foreach num2 of numlist 2012 2014 2016 {
  
mlogit lmst i.sex b6.agegrp1 i.educ_4cat [aw=expan_indiv] if round==`num2' , rrr b(3) 

estimates store estSA2_`num2'

foreach num1 of numlist 1/5 {

estimates restore estSA2_`num2'


margins, dydx(sex agegrp1 educ_4cat) post  predict(outcome(`num1'))

estimates store mfxSA2_`num2'_`num1'

}

*Men only
  
mlogit lmst i.sex b6.agegrp1 i.educ_4cat [aw=expan_indiv] if round==`num2' & sex==1, rrr b(3) 

estimates store estSA2_`num2'_men

foreach num1 of numlist 1/5 {

estimates restore estSA2_`num2'_men

margins, dydx(sex agegrp1 educ_4cat) post  predict(outcome(`num1'))


estimates store mfxSA2_`num2'_`num1'_men

}


}
 
 
*baseline probabilites 
 

foreach num2 of numlist 2012 2014 2016 {

foreach num1 of numlist 1/5 {

estimates restore estSA2_`num2'

margins, pr(outcome(`num1')) at(sex=1 agegrp1=6 educ_4cat=1)

}

*Men only
  
foreach num1 of numlist 1/5 {

estimates restore estSA2_`num2'_men

margins, pr(outcome(`num1')) at(sex=1 agegrp1=6 educ_4cat=1)


}


}
 
  
 
 
*Output 
esttab estSA* using "Graphs and Tables/ent_mlogit_rrr_SA.csv", ///
replace  cells(b(star fmt(%9.3f)) se(par)) nobase  ///     
stats(N r2, fmt(%9.0g %9.3f)) label  ///
mlabel("Multinomial Logit of Employment status relative risk ratios") ///
refcat(2.sex "Sex (male omit.)"  4.agegrp1 "Age group (30-39 omit.)" ///
 2.educ_4cat "Education (less than basic omit.)" ///
 , nolabel) eform ///
nobase noomit


esttab mfxSA* using "Graphs and Tables/ent_mlogit_mfx_SA.csv", ///
replace  cells(b(star fmt(%9.3f)) se(par)) nobase  ///     
stats(N r2, fmt(%9.0g %9.3f)) label  ///
mlabel("Multinomial Logit of Employment status relative risk ratios") ///
refcat(2.sex "Sex (male omit.)"  4.agegrp1 "Age group (30-39 omit.)" ///
 2.educ_4cat "Education (less than basic omit.)" ///
 , nolabel) ///
 noomit
  



**************
*Full income
**************

*Tunisia

use "Data/Tunisia/TLMPS 2014 v2.1 all.dta", clear

replace indid="788"+indid

destring round, replace

merge 1:1 indid using "Data/Tunisia/TLMPS 2014 full income for integration.dta"

*Into local currency, 2014
replace ipreinc=ipreinc*0.79*(167.1/148.9)
replace ipreinc=. if ipreinc==0

sum ipreinc mnthwgAllJob 
bysort usempstp: sum ipreinc mnthwgAllJob [aw=expan_indiv]
bysort usempstp: sum ipreinc mnthwgAllJob [aw=expan_indiv], detail

sum ipreinc [aw=expan_indiv], detail
*95th p is 1167

*Distribution

graph twoway kdensity ipreinc [aw=expan_indiv] if usempstp==2 & ipreinc<1167 & usemp1==1, ///
lcolor(gs3) lpatt("l") bw(100) || ///
kdensity ipreinc [aw=expan_indiv] if (usempstp==3 | usempstp==4) & ipreinc<1167 & usemp1==1, ///
lcolor(gs1) lpatt(dash) bw(100) || ///
kdensity mnthwgAllJob [aw=expan_indiv] if usempstp==1 & mnthwgAllJob<1167 & usemp1==1, ///
lcolor(gs10) lpatt(dash) bw(100) || ///
, note("") xtitle("Monthly income (2014 TD)") ///
ytitle("Density") legend(label(1 "Employers") label(2 "Self-employed") ///
label(3 "Wage workers")) plotregion(margin(zero)) xlabel(0(200)1000) ///
ylabel(0(0.0005)0.002) title("Tunisia")

graph save "Graphs and Tables/TN inc dist.gph", replace
graph export "Graphs and Tables/TN inc dist.png", replace

*Model


*Labor market status
gen lmst=.
*Wage worker
replace lmst=3 if usempstp==1 & usemp1==1
*Employer
replace lmst=1 if usempstp==2 & usemp1==1
*Self-employed or UFW
replace lmst=2 if (usempstp==3 | usempstp==4) & usemp1==1
*Unemployed, standard market definition
replace lmst=4 if usemp1==0 & unempsr1==1
*OLF
replace lmst=5 if usemp1==0 & unempsr1==0

label define Llmst 1 "Employer" 2 "Self-Employed" 3 "Wage worker" 4 "Unemployed" 5 "OLF" 

label values lmst Llmst
lab var lmst "Labor market status"

replace ipreinc=mnthwgAllJob if usempstp==1

gen l_ipreinc=ln(ipreinc)

replace agegrp1=5 if agegrp1==4
la def Lagegrp1 5 "15-29", modify

recode educlvl (1/2=1)(3=2)(4=3)(5/6=4), gen(educ_4cat)

tabu educ_4cat educlvl, miss

label define Leduc_4cat 1 "No education" 2 "Basic" 3 "Secondary" 4 "Higher Education"

label val educ_4cat Leduc_4cat
label var educ_4cat "Education level (four categories)"

reg l_ipreinc b3.lmst##i.educ_4cat b3.lmst##b6.agegrp1 ///
if age>=15 & age<=64 & usemp1==1 [aw=expan_indiv]

estimates store TN_inc

margins, over(lmst educ_4cat) at(agegrp1=5 agegrp1=6 agegrp1=7 agegrp1=8 agegrp1=9)

marginsplot , plotdim(lmst) ///
plotregion(margin(sides)) ///
ylabel(3(2)9) ytitle("Ln. monthly income (2014 TD)") ///
xtitle("Age group") ///
plot1opts(lcolor(gs1) lpatt(dash) mcolor(gs1)) ///
plot2opts(lcolor(gs4) lpatt(longdash) mcolor(gs4)) ///
plot3opts(lcolor(gs10) lpatt(shortdash) mcolor(gs10)) ///
ci1opts(lcolor(gs1)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs10)) ///
legend(off)

gr_edit .title.text = {}
gr_edit .title.text.Arrpush Tunisia


graph save "Graphs and Tables/TN inc model.gph", replace
graph export "Graphs and Tables/TN inc model.png", replace



*Egypt

use "Data/Egypt/elmps 2012 xs v2.3 all.dta", clear

replace indid="818"+indid

destring round, replace

merge 1:1 indid using "Data/Egypt/ELMPS 2012 full income for integration.dta"


*Labor market status
gen lmst=.
*Wage worker
replace lmst=3 if usempstp==1 & usemp1==1
*Employer
replace lmst=1 if usempstp==2 & usemp1==1
*Self-employed or UFW
replace lmst=2 if (usempstp==3 | usempstp==4) & usemp1==1
*Unemployed, standard market definition
replace lmst=4 if usemp1==0 & unempsr1==1
*OLF
replace lmst=5 if usemp1==0 & unempsr1==0

label define Llmst 1 "Employer" 2 "Self-Employed" 3 "Wage worker" 4 "Unemployed" 5 "OLF" 

label values lmst Llmst
lab var lmst "Labor market status"

*Into local currency
replace ipreinc=ipreinc*3.51
replace ipreinc=. if ipreinc==0

sum ipreinc mnthwgAllJob 
bysort lmst: sum ipreinc mnthwgAllJob [aw=expan]
bysort lmst: sum ipreinc mnthwgAllJob [aw=expan], detail

sum ipreinc [aw=expan], detail
*95th p is 3325

*Distribution

graph twoway kdensity ipreinc [aw=expan] if usempstp==2 & ipreinc<3325 & usemp1==1, ///
lcolor(gs3) lpatt("l") bw(200) || ///
kdensity ipreinc [aw=expan] if (usempstp==3 | usempstp==4) & ipreinc<3325 & usemp1==1, ///
lcolor(gs1) lpatt(dash) bw(200) || ///
kdensity mnthwgAllJob [aw=expan] if usempstp==1 & mnthwgAllJob<3325 & usemp1==1, ///
lcolor(gs10) lpatt(dash) bw(200) || ///
, note("") xtitle("Monthly income (2012 LE)") ///
ytitle("Density") legend(label(1 "Employers") label(2 "Self-employed") ///
label(3 "Wage workers")) plotregion(margin(zero)) xlabel(0(500)3000) ///
ylabel(0(0.0002)0.001) title("Egypt") 

graph save "Graphs and Tables/EG inc dist.gph", replace
graph export "Graphs and Tables/EG inc dist.png", replace

grc1leg "Graphs and Tables/EG inc dist.gph" "Graphs and Tables/TN inc dist.gph"

graph save "Graphs and Tables/inc dist.gph", replace
graph export "Graphs and Tables/inc dist.png", replace

*Model



replace ipreinc=mnthwgAllJob if usempstp==1

gen l_ipreinc=ln(ipreinc)

replace agegrp1=5 if agegrp1==4
la def Lagegrp1 5 "15-29" 6 "30-39" 7 "40-49" 8 "50-59" 9 "60-64", modify
la val agegrp1 Lagegrp1

recode educlvl (1/2=1)(3=2)(4=3)(5/6=4), gen(educ_4cat)

tabu educ_4cat educlvl, miss

label define Leduc_4cat 1 "No education" 2" Basic" 3 "Secondary" 4" Higher Education"

label val educ_4cat Leduc_4cat
label var educ_4cat "Education level (four categories)"

reg l_ipreinc b3.lmst##i.educ_4cat b3.lmst##b6.agegrp1 ///
if age>=15 & age<=64 & usemp1==1 [aw=expan]

estimates store EG_inc

margins, over(lmst educ_4cat) at(agegrp1=5 agegrp1=6 agegrp1=7 agegrp1=8 agegrp1=9)

marginsplot , plotdim(lmst) ///
plotregion(margin(sides)) ///
ylabel(3(2)9) ytitle("Ln. monthly income (2012 LE)") ///
xtitle("Age group") ///
plot1opts(lcolor(gs1) lpatt(dash) mcolor(gs1)) ///
plot2opts(lcolor(gs4) lpatt(longdash) mcolor(gs4)) ///
plot3opts(lcolor(gs10) lpatt(shortdash) mcolor(gs10)) ///
ci1opts(lcolor(gs1)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs10)) legend(off)

gr_edit .title.text = {}
gr_edit .title.text.Arrpush Egypt


graph save "Graphs and Tables/EG inc model.gph", replace
graph export "Graphs and Tables/EG inc model.png", replace

graph combine "Graphs and Tables/EG inc model.gph" "Graphs and Tables/TN inc model.gph", ///
col(1) 

graph display, xsize(12) ysize(20)

graph export "Graphs and Tables/inc model.png", replace







